@@ -198,9 +198,6 @@ class SoapController(controllers.Controller):
             raise validators.Invalid("Unknown SOAP method: %s" %
                                      methodname, methodname, None)
         
-        fi = method._ws_func_info
-        input_types = fi.input_types
-        
         params = {"_tgws" : True}
         params["xml_body"] = body
         
